# Refuel Python API

This is the [Refuel.ai](https://www.refuel.ai/) Python client library.

# Installation

You can install this library using `pip`:

```bash
pip install refuel
```

Make sure you have a valid API key from Refuel (shared with your team during onboarding).

# Questions?

Reach out to us at support@refuel.ai with any questions!

![Tests](https://github.com/refuel-ai/refuel-python/actions/workflows/test.yml/badge.svg)